@@ -1,9 +1,6 @@
 package Parse::MediaWikiDump::Links;
 
-#this needs to be fully replaced by MediaWiki::DumpFile::Compat
-#because it uses a much more correct SQL parser
-
-our $VERSION = '1.0.6';
+our $VERSION = '0.94';
 
 use strict;
 use warnings;
@@ -16,8 +13,7 @@ sub new {
 	bless($self, $class);
 
 	$self->open($source);
-	#fix for bug 58196 
-	#$self->init;
+	$self->init;
 
 	return $self;
 }
@@ -126,14 +122,6 @@ for extracting the indidivual article links to the same. Objects returned are an
     print 'from ', $link->from, ' to ', $link->namespace, ':', $link->to, "\n";
   }
 
-=head1 STATUS
-
-This software is being RETIRED - MediaWiki::DumpFile is the official successor to
-Parse::MediaWikiDump and includes a compatibility library called 
-MediaWiki::DumpFile::Compat that is API compatible with this module. Please
-begin testing MediaWiki::DumpFile::Compat and report success or failure
-to the author of this module. 
-
 =head1 METHODS
 
 =over 4
